document.addEventListener('DOMContentLoaded', () => {
    const wheel = document.getElementById('wheel');
    const spinBtn = document.getElementById('spinBtn');
    const scoreDisplay = document.getElementById('score');
    
    let score = 0;
    let canSpin = true;
    
    // Create wheel segments with colors
    const segments = document.querySelectorAll('.segment');
    const colors = ['#e74c3c', '#3498db', '#2ecc71', '#f1c40f', '#9b59b6', '#e67e22', '#1abc9c', '#34495e'];
    
    segments.forEach((segment, index) => {
        segment.style.transform = `rotate(${index * 45}deg)`;
        segment.style.background = colors[index];
    });

    function getRandomDegrees() {
        return Math.floor(Math.random() * 360) + 1440; // At least 4 full rotations
    }

    function calculatePrize(degrees) {
        const normalizedDegrees = degrees % 360;
        const segment = Math.floor(normalizedDegrees / 45);
        return (segment + 1) * 100;
    }

    function updateScore(prize) {
        score += prize;
        scoreDisplay.textContent = score;
        
        // Add animation to score display
        scoreDisplay.style.transform = 'scale(1.2)';
        setTimeout(() => {
            scoreDisplay.style.transform = 'scale(1)';
        }, 200);
    }

    spinBtn.addEventListener('click', () => {
        if (!canSpin) return;
        
        canSpin = false;
        spinBtn.disabled = true;
        
        const degrees = getRandomDegrees();
        wheel.style.transform = `rotate(${degrees}deg)`;
        
        // After spin completes
        setTimeout(() => {
            const prize = calculatePrize(degrees);
            updateScore(prize);
            canSpin = true;
            spinBtn.disabled = false;
            
            // Show celebration effect
            const celebration = document.createElement('div');
            celebration.className = 'celebration';
            document.body.appendChild(celebration);
            setTimeout(() => celebration.remove(), 1000);
        }, 4000);
    });

    // Add smooth transition for button state
    spinBtn.addEventListener('mousedown', () => {
        if (canSpin) {
            spinBtn.style.transform = 'scale(0.95)';
        }
    });

    spinBtn.addEventListener('mouseup', () => {
        spinBtn.style.transform = 'scale(1)';
    });
});
